# EchoAI

## installation
```
pip install echoai-free
```

## features
- Send prompts and get responses from free AI models  
- Minimal setup required  
- Simple, Pythonic interface  
- Supports multiple free AI models  

## Methods and Arguments
[**Method: Echo_AI.ChatClient()**

**Arguments: auth, model, system_prompt, message**]

## Example usage

```
import Echo_AI

response = Echo_AI.ChatClient(
    auth="OpenRouter API key.",
    model="nvidia/nemotron-3-nano-30b-a3b:free",
    system_prompt="You're a friendly, helpful, and intelligent AI assistant.",
    message="Hello!"
).json()

print(f"{response["choices"][0]["message"]["content"]}")
```

## How to get the API key
1. Open: https://openrouter.ai
2. Sign up or log in.
3. Click the "Get API key" button.
4. Give the API key a name.
